pub struct ModelPricing {
pub input_per_mtok: f64,
pub cached_input_per_mtok: f64,
pub output_per_mtok: f64,
}Fields
input_per_mtok: f64Rate for prompt tokens that missed the context cache. Also the fallback rate when cache stats are not reported.
cached_input_per_mtok: f64Rate for prompt tokens served from the context cache. Typically ~25%
of input_per_mtok.
output_per_mtok: f64Auto Trait Implementations
impl Freeze for ModelPricing
impl RefUnwindSafe for ModelPricing
impl Send for ModelPricing
impl Sync for ModelPricing
impl Unpin for ModelPricing
impl UnsafeUnpin for ModelPricing
impl UnwindSafe for ModelPricing